==> typescript-node-scripts-0.1.3.tgz: package/scripts/util/createJestConfig.js <==
const fs = require('fs')
const path = require('path')
const paths = require('../../lib/paths')
const tsconfig = require(paths.appTsConfig)

/**
 * Transform paths from tsconfig.json to Jest compatible path mappings
 * Transforms
 *   "@_util/*": ["src/_util/*"]
 * into
 *   "@_util/(.*)": "<rootdir>/src/_util/$1"
 * excluding global *
 * @param {json} config
 * @returns {object} key:value path mapping for jest
 */
const transformTsPathsToJestPaths = tsconfig => {
    const { paths = {}, baseUrl = '' } = tsconfig.compilerOptions
    const resolvedBase = path.join('<rootDir>', baseUrl)
    return Object.keys(paths).reduce(
        (acc, key) =>
            key === '*'
                ? acc
                : {
                      ...acc,
                      ['^' + key.replace('*', '(.*)') + '$']: path.join(
                          resolvedBase,
                          paths[key][0].replace('*', '$1')
                      )
                  },
        {}
    )
}

module.exports = (resolve, rootDir, srcRoots) => {
    const toRelRootDir = r => '<rootDir>/' + path.relative(rootDir || '', r)

    const config = {
        collectCoverageFrom: ['src/**.*.{js,ts,tsx}'],
        testMatch: [
            '**/__tests__/**/*.{js,jsx,ts,tsx}',
            '**/?(*.)(spec|test).{js,jsx,ts,tsx}'
        ],
        transform: {
            '^.+\\.(t|j)sx?$': 'ts-jest'
        },
        roots: srcRoots.map(toRelRootDir),
        testEnvironment: 'node',
        moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx'],
        globals: {
            'ts-jest': {
                tsConfigFile: paths.appTsTestConfig
            }
        },
        moduleNameMapper: transformTsPathsToJestPaths(tsconfig)
    }

    if (rootDir) {
        config.rootDir = rootDir
    }

    console.log(config)
    return config
}

==> typescript-node-scripts-0.1.4.tgz: package/scripts/util/createJestConfig.js <==
const fs = require('fs')
const path = require('path')
const paths = require('../../lib/paths')
const tsconfig = require(paths.appTsConfig)

/**
 * Transform paths from tsconfig.json to Jest compatible path mappings
 * Transforms
 *   "@_util/*": ["src/_util/*"]
 * into
 *   "@_util/(.*)": "<rootdir>/src/_util/$1"
 * excluding global *
 * @param {json} config
 * @returns {object} key:value path mapping for jest
 */
const transformTsPathsToJestPaths = tsconfig => {
    const { paths = {}, baseUrl = '' } = tsconfig.compilerOptions
    const resolvedBase = path.join('<rootDir>', baseUrl)
    return Object.keys(paths).reduce(
        (acc, key) =>
            key === '*'
                ? acc
                : {
                      ...acc,
                      ['^' + key.replace('*', '(.*)') + '$']: path.join(
                          resolvedBase,
                          paths[key][0].replace('*', '$1')
                      ),
                  },
        {}
    )
}

module.exports = (resolve, rootDir, srcRoots) => {
    const toRelRootDir = r => '<rootDir>/' + path.relative(rootDir || '', r)

    const config = {
        collectCoverageFrom: ['src/**.*.{js,ts,tsx}'],
        testMatch: [
            '**/__tests__/**/*.{js,jsx,ts,tsx}',
            '**/?(*.)(spec|test).{js,jsx,ts,tsx}',
        ],
        transform: {
            '^.+\\.(t|j)sx?$': 'ts-jest',
        },
        roots: srcRoots.map(toRelRootDir),
        testEnvironment: 'node',
        moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx'],
        globals: {
            'ts-jest': {
                tsConfigFile: paths.appTsTestConfig,
            },
        },
        moduleNameMapper: transformTsPathsToJestPaths(tsconfig),
    }

    if (rootDir) {
        config.rootDir = rootDir
    }

    return config
}
